context("getFeatureNames")

test_that("getFeatureNames", {
  g = getFeatureNames(testscenario1, "instance")
})
